@@ -60,6 +60,13 @@ extern Fl_Gl_Choice * gl_choice;
 // be sure to remove static declaration in gl_start.cxx in fltk src directory
 #endif
 
+#ifndef HAVE_PNG_H
+#undef HAVE_LIBPNG
+#endif
+#ifdef HAVE_LIBPNG
+#include <png.h>
+#endif
+
 using namespace std;
 using namespace giac;
 
@@ -914,7 +921,7 @@ namespace xcas {
 	  glGetLightfv(GL_LIGHT0+i,GL_SPOT_CUTOFF,&cutoff);
 	  glGetLightfv(GL_LIGHT0+i,GL_POSITION,posf);
 	  glGetLightfv(GL_LIGHT0+i,GL_SPOT_DIRECTION,direcf);
-	  direcf[4]=0;
+	  direcf[3]=0; // 4 was out of bound
 	  mult4(model_inv,posf,pos);
 	  tran4(model);
 	  mult4(model,direcf,direc);
@@ -2144,7 +2151,7 @@ namespace xcas {
 	  glGetLightfv(GL_LIGHT0+i,GL_SPOT_CUTOFF,&cutoff);
 	  glGetLightfv(GL_LIGHT0+i,GL_POSITION,posf);
 	  glGetLightfv(GL_LIGHT0+i,GL_SPOT_DIRECTION,direcf);
-	  direcf[4]=0;
+	  direcf[3]=0; // 4 was out of bound
 	  mult4(model_inv,posf,pos);
 	  tran4(model);
 	  mult4(model,direcf,direc);
